Sphinx Markup Constructs — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# Sphinx Markup Constructs

Sphinx adds a lot of new directives and interpreted text roles to standard reST markup. This section contains the reference material for these facilities.

- The TOC tree
  - Special names
- Paragraph-level markup
- Table-of-contents markup
- Index-generating markup
- Glossary
- Grammar production displays
- Showing code examples
  - Line numbers
  - Includes
- Inline markup
  - Cross-referencing syntax
    - Cross-referencing objects
    - Cross-referencing arbitrary locations
    - Cross-referencing documents
    - Referencing downloadable files
    - Cross-referencing other items of interest
  - Other semantic markup
  - Substitutions
- Miscellaneous markup
  - File-wide metadata
  - Meta-information markup
  - Including content based on tags
  - Tables

More markup is added by Sphinx Domains.

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »